pub enum FormationCompileError {
NoTemplate,
UncoveredRequirements {
unmatched_roles: Vec<SuggestorRole>,
unmatched_capabilities: Vec<SuggestorCapability>,
},
MissingProvider {
suggestor_id: SuggestorDescriptorId,
role: SuggestorRole,
},
DraftDescriptorMissing {
descriptor_id: SuggestorDescriptorId,
},
DuplicateDraftDescriptor {
descriptor_id: SuggestorDescriptorId,
},
}Variants
NoTemplate
UncoveredRequirements
MissingProvider
DraftDescriptorMissing
A draft passed to FormationCompiler::compile_draft_from_catalog
referenced a descriptor id that does not exist in the catalog.
Fields

descriptor_id: SuggestorDescriptorIdDuplicateDraftDescriptor
A draft passed to FormationCompiler::compile_draft_from_catalog
referenced the same descriptor id more than once.
Fields

descriptor_id: SuggestorDescriptorIdTrait Implementations
Sourceimpl Clone for FormationCompileError
impl Clone for FormationCompileError
Sourcefn clone(&self) -> FormationCompileError
fn clone(&self) -> FormationCompileError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormationCompileError
impl Debug for FormationCompileError
Sourceimpl Display for FormationCompileError
impl Display for FormationCompileError
Sourceimpl Error for FormationCompileError
impl Error for FormationCompileError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<FormationCompileError> for PipelineError
impl From<FormationCompileError> for PipelineError
Sourcefn from(source: FormationCompileError) -> Self
fn from(source: FormationCompileError) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for FormationCompileError
impl PartialEq for FormationCompileError
Sourcefn eq(&self, other: &FormationCompileError) -> bool
fn eq(&self, other: &FormationCompileError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for FormationCompileError
impl StructuralPartialEq for FormationCompileError